OC.L10N.register(
    "lib",
    {
    "Personal" : "Անձնական",
    "today" : "այսօր"
},
"nplurals=2; plural=(n != 1);");
